HapticInvocation class
Recorded haptic invocation record for test assertions.
Constructors
- HapticInvocation({required String method, AiroHapticFeedbackType? feedbackType, AiroHapticImpact? impact, AiroHapticPattern? pattern, double? intensity, double? sharpness, AiroHapticOptions? options, DateTime? timestamp})
-
const
Properties
- feedbackType → AiroHapticFeedbackType?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- impact → AiroHapticImpact?
-
final
- intensity → double?
-
final
- method → String
-
final
- options → AiroHapticOptions?
-
final
- pattern → AiroHapticPattern?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- timestamp → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited